@@ -2,8 +2,12 @@ function _aws_cdk_aws_iot_actions_FirehoseStreamRecordSeparator(p) {
 }
 function _aws_cdk_aws_iot_actions_CloudWatchLogsActionProps(p) {
 }
+function _aws_cdk_aws_iot_actions_CloudWatchPutMetricActionProps(p) {
+}
 function _aws_cdk_aws_iot_actions_CommonActionProps(p) {
 }
+function _aws_cdk_aws_iot_actions_CloudWatchPutMetricAction(p) {
+}
 function _aws_cdk_aws_iot_actions_LambdaFunctionAction(p) {
 }
 function _aws_cdk_aws_iot_actions_FirehoseStreamActionProps(p) {
@@ -14,10 +18,10 @@ function _aws_cdk_aws_iot_actions_FirehoseStreamActionProps(p) {
         _aws_cdk_aws_iot_actions_FirehoseStreamRecordSeparator(p.recordSeparator);
     visitedObjects.delete(p);
 }
-function _aws_cdk_aws_iot_actions_FirehoseStreamAction(p) {
-}
 function _aws_cdk_aws_iot_actions_CloudWatchLogsAction(p) {
 }
+function _aws_cdk_aws_iot_actions_FirehoseStreamAction(p) {
+}
 function _aws_cdk_aws_iot_actions_S3PutObjectAction(p) {
 }
 function _aws_cdk_aws_iot_actions_S3PutObjectActionProps(p) {
@@ -37,5 +41,5 @@ function print(name, deprecationMessage) {
 const visitedObjects = new Set();
 class DeprecationError extends Error {
 }
-module.exports = { print, _aws_cdk_aws_iot_actions_FirehoseStreamRecordSeparator, _aws_cdk_aws_iot_actions_CloudWatchLogsActionProps, _aws_cdk_aws_iot_actions_CommonActionProps, _aws_cdk_aws_iot_actions_LambdaFunctionAction, _aws_cdk_aws_iot_actions_FirehoseStreamActionProps, _aws_cdk_aws_iot_actions_FirehoseStreamAction, _aws_cdk_aws_iot_actions_CloudWatchLogsAction, _aws_cdk_aws_iot_actions_S3PutObjectAction, _aws_cdk_aws_iot_actions_S3PutObjectActionProps };
+module.exports = { print, _aws_cdk_aws_iot_actions_FirehoseStreamRecordSeparator, _aws_cdk_aws_iot_actions_CloudWatchLogsActionProps, _aws_cdk_aws_iot_actions_CloudWatchPutMetricActionProps, _aws_cdk_aws_iot_actions_CommonActionProps, _aws_cdk_aws_iot_actions_CloudWatchPutMetricAction, _aws_cdk_aws_iot_actions_LambdaFunctionAction, _aws_cdk_aws_iot_actions_FirehoseStreamActionProps, _aws_cdk_aws_iot_actions_CloudWatchLogsAction, _aws_cdk_aws_iot_actions_FirehoseStreamAction, _aws_cdk_aws_iot_actions_S3PutObjectAction, _aws_cdk_aws_iot_actions_S3PutObjectActionProps };
 module.exports.DeprecationError = DeprecationError;
